//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
// 
// uIOcntl.h -- 
// 
// Author           : Peter Buhr
// Created On       : Tue Mar 29 16:49:48 1994
// Last Modified By : Peter A. Buhr
// Last Modified On : Thu Sep  6 11:37:21 2007
// Update Count     : 56
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_IOCNTL_H__
#define __U_IOCNTL_H__

#include <uPoll.h>

#pragma __U_NOT_USER_CODE__


//######################### uIOaccess #########################


struct uIOaccess {
    int fd;
    uPoll poll;
}; // uIOaccess


struct uIOClosure {
    uIOaccess &access;
    int &retcode;

    uIOClosure( uIOaccess &access, int &retcode ) : access( access ), retcode( retcode ) {}
    virtual ~uIOClosure() {}

    int wrapper( int rwe );
    virtual int action( int rwe ) = 0;
}; // uIOClosure


#pragma __U_USER_CODE__

#endif // __U_IOCNTL_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
